@@ -11,8 +11,16 @@ __all__ = ["CID"]
 BUFSIZE = 4 * 1024 * 1024
 
 
+def is_hex(x: str):
+    hset = set("0123456789abcdef")
+    xset = set(x)
+    return len(hset & xset) == len(xset)
+
+
 class CID:
     def __init__(self, sha256hex: str):
+        if len(sha256hex) != 64 or not is_hex(sha256hex):
+            raise ValueError(f"Not a valid sha256hex: {sha256hex}")
         self._sha256hex = sha256hex
 
     @classmethod
@@ -22,6 +30,9 @@ class CID:
     def hex(self) -> str:
         return self._sha256hex
 
+    def __eq__(self, x: CID):
+        return x.hex() == self.hex()
+
 
 def digest(file: Path, progress: Progress) -> str:
     h = hashlib.sha256()
